# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import gnomock
from gnomock.api.presets_api import PresetsApi  # noqa: E501
from gnomock.rest import ApiException


class TestPresetsApi(unittest.TestCase):
    """PresetsApi unit test stubs"""

    def setUp(self):
        self.api = gnomock.api.presets_api.PresetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_start_localstack(self):
        """Test case for start_localstack

        Start a new Gnomock Localstack container  # noqa: E501
        """
        pass

    def test_start_mongo(self):
        """Test case for start_mongo

        Start a new Gnomock MongoDB container  # noqa: E501
        """
        pass

    def test_start_mssql(self):
        """Test case for start_mssql

        Start a new Gnomock Microsoft SQL Server container  # noqa: E501
        """
        pass

    def test_start_mysql(self):
        """Test case for start_mysql

        Start a new Gnomock MySQL container  # noqa: E501
        """
        pass

    def test_start_postgres(self):
        """Test case for start_postgres

        Start a new Gnomock Postgres container  # noqa: E501
        """
        pass

    def test_start_redis(self):
        """Test case for start_redis

        Start a new Gnomock Redis container  # noqa: E501
        """
        pass

    def test_start_splunk(self):
        """Test case for start_splunk

        Start a new Gnomock Splunk container  # noqa: E501
        """
        pass

    def test_stop(self):
        """Test case for stop

        Stop an existing Gnomock container  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
