# coding: utf-8

"""
    gnomock

    `gnomock` is an HTTP wrapper for [Gnomock](https://github.com/orlangure/gnomock) integration and end-to-end testing toolkit. It allows to use Gnomock outside of Go ecosystem. Not all Gnomock features exist in this wrapper, but official presets, as well as basic general configuration, are supported.   # noqa: E501

    The version of the OpenAPI document: 1.4.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import gnomock
from gnomock.models.memcached_request import MemcachedRequest  # noqa: E501
from gnomock.rest import ApiException

class TestMemcachedRequest(unittest.TestCase):
    """MemcachedRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MemcachedRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = gnomock.models.memcached_request.MemcachedRequest()  # noqa: E501
        if include_optional :
            return MemcachedRequest(
                preset = gnomock.models.memcached.Memcached(
                    values = {"computer":"hal9000"}, 
                    byte_values = {"foo":"YmFy","baz":"NDI=","meh":"My4xNA=="}, 
                    version = 'latest', ), 
                options = gnomock.models.options.Options(
                    timeout = 60000000000, 
                    env = [
                        'ENV_VAR_NAME=some-value'
                        ], 
                    debug = True, 
                    container_name = 'gnomock', )
            )
        else :
            return MemcachedRequest(
        )

    def testMemcachedRequest(self):
        """Test MemcachedRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
